Index: sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart |
diff --git a/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart b/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart |
index 83cc9c26e56322565ec19066e04d91ee72a6fb30..03fcf72fed5f50e945b1eb69db0217ea4ad9165d 100644 |
--- a/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart |
+++ b/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart |
@@ -104,16 +104,16 @@ enum JsBuiltin { |
/// ... |
dartObjectConstructor, |
/// Returns the class name given an [isCheckProperty]. |
/// |
/// This relies on a deterministic encoding of is-check properties (for |
/// example `$isFoo` for a class `Foo`). In minified code the returned |
/// classname is the minified name of the class. |
/// |
/// JS_BUILTIN('returns:String;depends:none;effects:none', |
- /// JsBuiltin.classNameFromIsCheckProperty, |
+ /// JsBuiltin.isCheckPropertyToJsConstructorName, |
/// isCheckProperty); |
- classNameFromIsCheckProperty, |
+ isCheckPropertyToJsConstructorName, |
/// Returns true if the given type is a function type. Returns false for |
/// the one `Function` type singleton. (See [isFunctionTypeSingleton]). |
@@ -124,12 +124,12 @@ enum JsBuiltin { |
/// Returns a new function type object. |
/// |
/// JS_BUILTIN('=Object', JsBuiltin.createFunctionType) |
- createFunctionType, |
+ createFunctionTypeRti, |
- /// Returns the class name of the given type. |
+ /// Returns the JavaScript-constructor name given an rti encoding. |
/// |
- /// JS_BUILTIN('String', JsBuiltin.typeName, type) |
- typeName, |
+ /// JS_BUILTIN('String', JsBuiltin.rawRtiToJsConstructorName, rti) |
+ rawRtiToJsConstructorName, |
/// Returns the raw runtime type of the given object. The given argument |
/// [o] should be the interceptor (for non-Dart objects). |
@@ -104,16 +104,16 @@ enum JsBuiltin { |
/// ... |
dartObjectConstructor, |
- /// Returns the class name given an [isCheckProperty]. |
+ /// Returns the JavaScript-constructor name given an [isCheckProperty]. |
/// |
/// This relies on a deterministic encoding of is-check properties (for |